=======================================
Welcome to django-environ documentation
=======================================

Release v\ |release| (`What's new? <changelog>`).

.. include:: ../README.rst
   :start-after: -teaser-begin-
   :end-before: -teaser-end-

Overview
========

.. include:: ../README.rst
   :start-after: -overview-
   :end-before: -project-information-

Quick Start
===========

.. include:: ../README.rst
   :start-after: -code-begin-
   :end-before: -overview-

.. include:: ../README.rst
   :start-after: -support-

----

Full Table of Contents
======================

.. toctree::
   :maxdepth: 2

   getting-started
   types
   tips
   contributing
   backers

.. include:: ../README.rst
   :start-after: -project-information-
   :end-before: -support-

.. toctree::
   :maxdepth: 1

   license
   changelog
